@@ -1,8 +1,9 @@
-from orredis.orredis import Store
+from orredis.orredis import Store, AsyncStore
 
 from .abstract import Model
 
 __all__ = [
+    AsyncStore,
     Store,
     Model,
 ]
